<?php
/**
 * Smart Wishlist Admin Notice
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @since 1.2.0
 * @version 1.2.1
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'WLFMC_Admin_Notice' ) ) {
	/**
	 * This class handles admin_notice for wishlist plugin
	 */
	class WLFMC_Admin_Notice {

		/**
		 * Single instance of the class
		 *
		 * @var WLFMC_Admin_Notice
		 */
		protected static $instance;

		/**
		 * Constructor
		 *
		 * @return void
		 */
		public function __construct() {
			add_action( 'admin_notices', array( $this, 'notice' ) );
			add_action( 'admin_init', array( $this, 'dismiss_notice' ) );
			add_action( 'admin_notices', array( $this, 'after_skip_wizard' ) );
			add_action( 'admin_notices', array( $this, 'after_finish_wizard' ) );
		}

		/**
		 * Add admin delyed notice.
		 *
		 * @since 1.2.1
		 * @version 1.2.1
		 */
		public function notice() {

			if ( ! is_super_admin() || true == get_option('wlfmc_notice_disabled') ) {
				return;
			}
			$activate_date = get_option( 'wlfmc_wishlist_activation_date' );
			$today         = strtotime(date('Y-m-d'));
			if(! $activate_date) {
				update_option( 'wlfmc_wishlist_activation_date' , $today );
				$activate_date = $today ;
			}else{
				$activate_date = strtotime($activate_date);
			}


			$args = array(
				array(
					'title'       => '<span class="green-text">' . __( 'Need MC Wishlist Customization?', 'wc-wlfmc-wishlist' ) . '</span>',
					'content'     => __( 'Some websites have non-standard themes and plugins that decrease the quality of displaying the wishlist button and page.<br>We can customize the plugin and add some futures for you, send a ticket to us.', 'wc-wlfmc-wishlist' ),
					'btn_title'   => __( 'Ask for Customize', 'wc-wlfmc-wishlist' ),
					'btn_class'   => 'green-btn',
					'btn_url'     => 'https://moreconvert.com/support/',
					'btn_target'  => '_blank',
					'dismiss_url' => '',
				),
				array(
					'title'       => '<span class="orange-text">' . __( 'Congratulations!', 'wc-wlfmc-wishlist' ) . ' </span>' . __( 'Your gift for installing MC Wishlist plugin', 'wc-wlfmc-wishlist' ),
					'content'     => __( 'You have been invited to a very valuable $300 course in which you will learn how to increase your sales without increasing site traffic.<br>Sign up for this course right now!', 'wc-wlfmc-wishlist' ),
					'btn_title'   => __( 'Lets Go', 'wc-wlfmc-wishlist' ),
					'btn_class'   => 'orange-btn inverse-btn',
					'btn_url'     => 'https://moreconvert.com/gift-wishlist',
					'btn_target'  => '_blank',
					'dismiss_url' => '',
				),

				array(
					'title'       => __( 'How can we improve MC Wishlist plugin?', 'wc-wlfmc-wishlist' ),
					'content'     => __( 'You have been using  MC Wishlist plugin for ten days now, please take part in the following poll and share your ideas, problems, and comments to improve MC Wishlist plugin or any other idea.', 'wc-wlfmc-wishlist' ),
					'btn_title'   => __( 'I fill the form', 'wc-wlfmc-wishlist' ),
					'btn_class'   => 'purple-btn',
					'btn_url'     => 'https://moreconvert.com/poll-wishlist',
					'btn_target'  => '_blank',
					'dismiss_url' => '',
				)
			);

			$notice_after_days = array(
				'3'  => $args[0],
				'7'  => $args[1],
				'10' => $args[2],
				'15' => $args[0],
				'16' => $args[1],
				'30' => $args[2],
				'35' => $args[1],
			);
			foreach ( $notice_after_days as $day => $notice_args ) {
				$day = intval($day);
				if ( '1' != get_option('wlfmc-disable-notice-after-'.$day.'-days' ) ) {

					if(strtotime( '+'.$day.' days', $activate_date) <= $today ) {
						$dismiss_nonce = wp_create_nonce( 'wlfmc-after-days-notice' );
						update_option('wlfmc_wishlist_activation_date',date('y-m-d H:i:s', strtotime('-'.$day.' days' ,$today )));
						$notice_args['dismiss_url'] = add_query_arg(array('wlfmc-notice-after-'.$day.'-days-dismiss' => '1' , '_wpnonce'    => $dismiss_nonce));
						$this->output( $notice_args );
					}
					break;
				}
			}
		}


		/**
		 * Dismise Notice.
		 *
		 */
		public function dismiss_notice() {


			if ( isset( $_GET['mct-wlfmc_options-wizard-skip'] ) && '1' == $_GET['mct-wlfmc_options-wizard-skip']  ) {

				update_option( 'wlfmc-skip-wizard-notice', false );

			}

			if ( isset( $_GET['mct-wlfmc_options-wizard-finish'] ) && '1' == $_GET['mct-wlfmc_options-wizard-finish']  ) {

				update_option( 'wlfmc-finish-wizard-notice', false );

			}

			if ( isset( $_GET['wlfmc-skip-wizard-dismiss'] ) && '1' == $_GET['wlfmc-skip-wizard-dismiss'] ) {

				update_option( 'wlfmc-skip-wizard-notice', true );

			}

			if ( isset( $_GET['wlfmc-finish-wizard-dismiss'] ) && '1' == $_GET['wlfmc-finish-wizard-dismiss']) {

				update_option( 'wlfmc-finish-wizard-notice', true );

			}
			if(isset($_GET['wlfmc-show-tracking-notice']) &&  '1' == $_GET['wlfmc-show-tracking-notice'] ) {

				delete_option(  'smart-wishlist-for-more-convert_tracking_notice' );

			}

			$notice_after_days = array( '3', '7', '10', '15', '16', '30', '35', );
			$nonce = isset($_REQUEST['_wpnonce'] ) ? esc_attr( $_REQUEST['_wpnonce'] ) : '';

			foreach ($notice_after_days as $day){

				if ( isset( $_GET['wlfmc-notice-after-'.$day.'-days-dismiss'] ) && '1' == $_GET['wlfmc-notice-after-'.$day.'-days-dismiss'] &&  wp_verify_nonce( $nonce, 'wlfmc-after-days-notice' )) {

					update_option( 'wlfmc-disable-notice-after-'.$day.'-days', true );

				}

			}
		}

		/**
		 * Add admin notice after skip wizard.
		 */
		public function after_skip_wizard() {

			if ( ! is_super_admin() || '1' == get_option( 'wlfmc-skip-wizard-notice' ) ) {
				return;
			}

            $dismiss_url = remove_query_arg(array('mct-wlfmc_options-wizard-skip','mct-wlfmc_options-wizard-finish'));

			$args = array(
				'wrapper_class' => 'notice-skip-wizard',
				'title'       => __( 'Thanks for installing MC Wishlist!', 'wc-wlfmc-wishlist' ),
				'content'     => __( 'It is easy to use the MC Wishlist. Please use the setup wizard to quick start setup.', 'wc-wlfmc-wishlist' ),
				'btn_title'   => __( 'Start Wizard', 'wc-wlfmc-wishlist' ),
				'btn_class'   => 'blue-btn',
				'btn_url'     => add_query_arg(  array('wlfmc-skip-wizard-dismiss' =>  1  , 'wlfmc-show-tracking-notice' => 1)  , get_admin_url() . 'index.php?page=mc-wishlist-setup'),
				'btn_target'  => '_self',
				'dismiss_url' => add_query_arg( array('wlfmc-skip-wizard-dismiss' =>  1  , 'wlfmc-show-tracking-notice' => 1)   , $dismiss_url),
			);

			$this->output( $args );

		}

		/**
		 * Add admin notice after finish wizard.
		 */
		public function after_finish_wizard() {
			if ( ! is_super_admin() || '1' == get_option( 'wlfmc-finish-wizard-notice' ) ) {
				return;
			}
			$dismiss_url = remove_query_arg(array('mct-wlfmc_options-wizard-skip','mct-wlfmc_options-wizard-finish'));


			$args = array(
				'wrapper_class' => 'notice-finish-wizard',
				'title'       => __( 'Together we will increase your sales.', 'wc-wlfmc-wishlist' ),
				'content'     => __( 'Thank you for installing MC Wishlist plugin. Our main goal and challenge are to increase your site sales without the need for more traffic, and effortlessly, if you would like to join us in this challenge, be sure to check the marketing settings and documentation right now. ', 'wc-wlfmc-wishlist' ),
				'btn_title'   => __( "Let's Go Marketing", "wc-wlfmc-wishlist" ),
				'btn_class'   => '',
				'btn_url'     => add_query_arg( 'wlfmc-finish-wizard-dismiss', 1 , get_admin_url() . 'admin.php?page=mc-wishlist-marketing'),
				'btn_target'  => '_self',
				'dismiss_url' => add_query_arg( 'wlfmc-finish-wizard-dismiss', 1 , $dismiss_url),
			);

			$this->output( $args );

		}

		/**
		 * print admin notice
		 *
		 * @param array $args
		 */
		public function output( $args ) {

			?>
			<style>
				@font-face {
					font-family: "Montserrat";
					font-weight: 400;
					font-style: normal;
					src: url("<?php echo MC_WLFMC_URL;?>assets/font/Montserrat-Regular.woff2") format("woff2"), url("<?php echo MC_WLFMC_URL;?>assets/font/Montserrat-Regular.woff") format("woff");
				}

				@font-face {
					font-family: "Montserrat";
					font-weight: 600;
					font-style: normal;
					src: url("<?php echo MC_WLFMC_URL;?>assets/font/Montserrat-SemiBold.woff2") format("woff2"), url("<?php echo MC_WLFMC_URL;?>assets/font/Montserrat-SemiBold.woff") format("woff");
				}
				.mct-wizard-page .wlfmc-notice.notice-finish-wizard ,.mct-wizard-page  .wlfmc-notice.notice-skip-wizard {
					display: none !important;
				}
				.wlfmc-notice {
					padding: 20px !important;
					-webkit-border-radius: 8px;
					border-radius: 8px;
					background: #fff;
					border: 1px solid #e4dbd0;
					-webkit-box-shadow: 0px 6px 6px rgba(0, 0, 0, 0.08);
					box-shadow: 0px 6px 6px rgba(0, 0, 0, 0.08);
					position: relative;
					font-family: Montserrat, "Helvetica Neue", sans-serif;
					font-weight: normal;
				}

				.wlfmc-notice h2 {
					font-size: 24px;
					font-weight: 600;
					margin-top: 0;
				}

				.wlfmc-notice .dismiss-btn {
					font-size: 14px;
					line-height: 21px;
					color: #302a23;
					position: absolute;
					right: 20px;
					top: 20px;
					text-decoration: none;
				}

				.wlfmc-notice p {
					font-size: 13px;
					line-height: 21px;
					color: #302a23;
				}

				.wlfmc-notice .btn-notice {
					border: none !important;
					color: #fff;
					height: 40px;
					line-height: 40px;
					min-width: 40px;
					-webkit-border-radius: 8px;
					border-radius: 8px;
					position: relative;
					font-size: 14px;
					font-weight: normal;
					-webkit-transition: all .3s ease-in-out;
					-o-transition: all .3s ease-in-out;
					transition: all .3s ease-in-out;
					display: inline-block;
					text-decoration: none;
					padding: 0 10px;
					cursor: pointer;
					-webkit-appearance: none;
					white-space: nowrap;
					-webkit-box-sizing: border-box;
					box-sizing: border-box;
					vertical-align: top;
					overflow: hidden;
					background-color: white;
					padding-left: 40px;
					-webkit-box-shadow: 0 2px 4px rgba(0, 0, 0, 0.16);
					box-shadow: 0 2px 4px rgba(0, 0, 0, 0.16);
					z-index: 1;
				}

				.wlfmc-notice .btn-notice .dashicons {
					line-height: 40px;
				}

				.wlfmc-notice .btn-notice:hover {
					color: #fff;
				}

				.wlfmc-notice .btn-notice:focus {
					-webkit-box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.26);
					box-shadow: 0px 2px 4px rgba(0, 0, 0, 0.26);
				}

				.wlfmc-notice .btn-notice:before {
					font-family: Dashicons;
					font-weight: 400;
					font-variant: normal;
					text-transform: none;
					line-height: 1;
					-webkit-font-smoothing: antialiased;
					margin: 0;
					text-indent: 0;
					position: absolute;
					top: 0;
					left: 10px;
					text-align: center;
					font-size: 19px;
					line-height: inherit;
					content: "\f147";
					color: #ea7a0b;
				}

				.wlfmc-notice .btn-notice:after {
					position: absolute;
					-webkit-transition: .3s;
					-o-transition: .3s;
					transition: .3s;
					content: '';
					width: 100%;
					bottom: 0;
					height: 100%;
					right: -35px;
					-webkit-transform: skewX(15deg);
					-ms-transform: skewX(15deg);
					transform: skewX(15deg);
					z-index: -1;
					background-color: #ea7a0b;
					-webkit-border-top-left-radius: 2px;
					border-top-left-radius: 2px;
				}

				.wlfmc-notice .btn-notice:hover {
					color: #ea7a0b;
				}

				.wlfmc-notice .btn-notice:hover:after {
					right: -120%;
				}

				.wlfmc-notice .btn-notice.green-btn:before,
				.wlfmc-notice .btn-notice.green-btn:hover {
					color: #91ca45 !important;
				}

				.wlfmc-notice .btn-notice.green-btn:after {
					background-color: #91ca45;
				}

				.wlfmc-notice .btn-notice.purple-btn:before,
				.wlfmc-notice .btn-notice.purple-btn:hover {
					color: #a45eff !important;
				}

				.wlfmc-notice .btn-notice.purple-btn:after {
					background-color: #a45eff;
				}

				.wlfmc-notice .btn-notice.blue-btn:before,
				.wlfmc-notice .btn-notice.blue-btn:hover {
					color: #5e94ff !important;
				}

				.wlfmc-notice .btn-notice.blue-btn:after {
					background-color: #5e94ff;
				}

				.wlfmc-notice .btn-notice.inverse-btn {
					border: 1px solid #ea7a0b !important;
					color: #ea7a0b;
					-webkit-box-shadow: none !important;
					box-shadow: none !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn:before {
					color: #fff !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn:after {
					left: -webkit-calc(-100% + 35px);
					left: calc(-100% + 35px);
					right: auto;
					-webkit-transform: skewX(15deg);
					-ms-transform: skewX(15deg);
					transform: skewX(15deg);
				}

				.wlfmc-notice .btn-notice.inverse-btn:hover {
					color: #fff !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn:hover:after {
					right: auto;
					left: 0;
					-webkit-transform: skewX(0deg);
					-ms-transform: skewX(0deg);
					transform: skewX(0deg);
				}

				.wlfmc-notice .btn-notice.inverse-btn.green-btn {
					border-color: #91ca45 !important;
					color: #91ca45 !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn.green-btn:after {
					background-color: #91ca45 !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn.green-btn:hover {
					color: #fff !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn.purple-btn {
					border-color: #a45eff !important;
					color: #a45eff !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn.purple-btn:after {
					background-color: #a45eff !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn.purple-btn:hover {
					color: #fff !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn.blue-btn {
					border-color: #5e94ff !important;
					color: #5e94ff !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn.blue-btn:after {
					background-color: #5e94ff !important;
				}

				.wlfmc-notice .btn-notice.inverse-btn.blue-btn:hover {
					color: #fff !important;
				}

				.wlfmc-notice .green-text {
					color: #91ca45
				}

				.wlfmc-notice .orange-text {
					color: #ea7a0b;
				}

				.rtl .wlfmc-notice .dismiss-btn {
					left:20px ;
					right: auto !important;
				}
			</style>
			<div class="notice wlfmc-notice <?php echo isset($args['wrapper_class'] ) ? esc_attr( $args['wrapper_class'] ):''; ?>">
				<h2><?php echo wp_kses_post( $args['title'] ); ?></h2>
				<a href="<?php echo esc_url( $args['dismiss_url'] ); ?>" class="dismiss-btn">
					<?php _e( 'close', 'wc-wlfmc-wishlist' ); ?>
				</a>
				<p>
					<?php echo wp_kses_post( $args['content'] ); ?>
				</p>
				<p style="text-align:<?php echo is_rtl() ? 'left' : 'right'; ?>">
					<a href="<?php echo esc_url( $args['btn_url'] ); ?>"
					   class="btn-notice <?php echo esc_attr( $args['btn_class'] ); ?>"
					   target="<?php echo esc_attr( $args['btn_target'] ); ?>">
						<?php echo esc_attr( $args['btn_title'] ); ?>
					</a>
				</p>
			</div>
			<?php
		}


		/**
		 * Returns single instance of the class
		 *
		 * @return WLFMC_Admin_Notice
		 */
		public static function get_instance() {
			if ( is_null( self::$instance ) ) {
				self::$instance = new self();
			}

			return self::$instance;
		}
	}
}
/**
 * Unique access to instance of WLFMC_Admin_Notice class
 *
 * @return WLFMC_Admin_Notice
 */
function WLFMC_Admin_Notice() {
	return WLFMC_Admin_Notice::get_instance();
}
